#ifndef NT2_INCLUDE_FUNCTIONS_BITOFSIGN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BITOFSIGN_HPP_INCLUDED

#include <nt2/ieee/include/functions/bitofsign.hpp>

#endif
